@@ -1,27 +1,24 @@
-/* echo.c, taken from Bash.
-   Copyright (C) 87, 89, 91, 92, 93, 1994 Free Software Foundation, Inc.
+/* echo.c, derived from code echo.c in Bash.
+   Copyright (C) 87, 89, 91, 92, 93, 94, 95, 1996 Free Software Foundation, Inc.
 
-This file is part of GNU Bash, the Bourne Again SHell.
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
 
-Bash is free software; you can redistribute it and/or modify it under
-the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
-version.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-Bash is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License along
-with Bash; see the file COPYING.  If not, write to the Free Software
-Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include "system.h"
-#include "version.h"
 #include "long-options.h"
 
 /* echo [-neE] [arg ...]
@@ -64,16 +61,16 @@ on System V systems with the -E option.
 char *program_name;
 
 static void
-usage (status)
-     int status;
+usage (int status)
 {
   if (status != 0)
-    fprintf (stderr, "Try `%s --help' for more information.\n",
+    fprintf (stderr, _("Try `%s --help' for more information.\n"),
 	     program_name);
   else
     {
-      printf ("Usage: %s [OPTION]... [STRING]...\n", program_name);
-      printf ("\
+      printf (_("Usage: %s [OPTION]... [STRING]...\n"), program_name);
+      printf (_("\
+Echo the STRING(s) to standard output.\n\
 \n\
   -n              do not output the trailing newline\n\
   -e              (unused)\n\
@@ -93,7 +90,8 @@ Without -E, the following sequences are recognized and interpolated:\n\
   \\r     carriage return\n\
   \\t     horizontal tab\n\
   \\v     vertical tab\n\
-");
+"));
+      puts (_("\nReport bugs to sh-utils-bugs@gnu.ai.mit.edu"));
     }
   exit (status);
 }
@@ -101,16 +99,20 @@ Without -E, the following sequences are recognized and interpolated:\n\
 /* Print the words in LIST to standard output.  If the first word is
    `-n', then don't print a trailing newline.  We also support the
    echo syntax from Version 9 unix systems. */
-void
-main (argc, argv)
-     int argc;
-     char **argv;
+
+int
+main (int argc, char **argv)
 {
   int display_return = 1, do_v9 = 0;
 
   program_name = argv[0];
+  setlocale (LC_ALL, "");
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  textdomain (PACKAGE);
 
-  parse_long_options (argc, argv, "echo", version_string, usage);
+  /* Don't recognize --help or --version if POSIXLY_CORRECT is set.  */
+  if (getenv ("POSIXLY_CORRECT") == NULL)
+    parse_long_options (argc, argv, "echo", GNU_PACKAGE, VERSION, usage);
 
 /* System V machines already have a /bin/sh with a v9 behaviour.  We
    use the identical behaviour for these machines so that the
@@ -134,7 +136,7 @@ main (argc, argv)
 
       for (i = 0; temp[i]; i++)
 	{
-	  if (rindex (VALID_ECHO_OPTIONS, temp[i]) == 0)
+	  if (strrchr (VALID_ECHO_OPTIONS, temp[i]) == 0)
 	    goto just_echo;
 	}
 
