@@ -13,8 +13,8 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# along with this program; if not, write to the Free Software Foundation,
+# Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 # Written by David MacKenzie <djm@gnu.ai.mit.edu>.
 
@@ -27,15 +27,17 @@ usage="Usage: $0 [OPTION]... [USERNAME]...
   --help      display this help and exit
   --version   output version information and exit
 
-Same as id -Gn.  If no USERNAME, use current process."
+Same as id -Gn.  If no USERNAME, use current process.
+
+Report bugs to sh-utils-bugs@gnu.ai.mit.edu"
 
 case $# in
   1 )
-    case "z${1}" in 
+    case "z${1}" in
       z--help )
 	 echo "$usage"; exit 0 ;;
       z--version )
-	 echo "groups - @VERSION@"; exit 0 ;;
+	 echo "groups (@GNU_PACKAGE@) @VERSION@"; exit 0 ;;
       * ) ;;
     esac
     ;;
