@@ -1,5 +1,5 @@
 /* id -- print real and effective UIDs and GIDs
-   Copyright (C) 89, 90, 91, 92, 93, 1994 Free Software Foundation, Inc.
+   Copyright (C) 1989-1995, 1996 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,8 +12,8 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* Written by Arnold Robbins, arnold@audiofax.com.
    Major rewrite by David MacKenzie, djm@gnu.ai.mit.edu. */
@@ -26,15 +26,11 @@
 #include <grp.h>
 #include <getopt.h>
 
-#include "version.h"
 #include "system.h"
+#include "error.h"
 
 #ifdef _POSIX_VERSION
 #include <limits.h>
-#if !defined(NGROUPS_MAX) || NGROUPS_MAX < 1
-#undef NGROUPS_MAX
-#define NGROUPS_MAX sysconf (_SC_NGROUPS_MAX)
-#endif /* !NGROUPS_MAX */
 
 #else /* not _POSIX_VERSION */
 struct passwd *getpwuid ();
@@ -44,20 +40,16 @@ gid_t getgid ();
 uid_t geteuid ();
 gid_t getegid ();
 #include <sys/param.h>
-#if !defined(NGROUPS_MAX) && defined(NGROUPS)
-#define NGROUPS_MAX NGROUPS
-#endif /* not NGROUPS_MAX and NGROUPS */
 #endif /* not _POSIX_VERSION */
 
 char *xmalloc ();
 int getugroups ();
-void error ();
 
-static void print_user ();
-static void print_group ();
-static void print_group_list ();
-static void print_full_info ();
-static void usage ();
+static void print_user __P ((int uid));
+static void print_group __P ((int gid));
+static void print_group_list __P ((char *username));
+static void print_full_info __P ((char *username));
+static void usage __P ((int status));
 
 /* The name this program was run with. */
 char *program_name;
@@ -84,10 +76,10 @@ static gid_t rgid, egid;
 /* The number of errors encountered so far. */
 static int problems = 0;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const longopts[] =
@@ -102,22 +94,26 @@ static struct option const longopts[] =
   {NULL, 0, NULL, 0}
 };
 
-void
-main (argc, argv)
-     int argc;
-     char **argv;
+int
+main (int argc, char **argv)
 {
   int optc;
 
   program_name = argv[0];
+  setlocale (LC_ALL, "");
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  textdomain (PACKAGE);
 
-  while ((optc = getopt_long (argc, argv, "gnruG", longopts, (int *) 0))
+  while ((optc = getopt_long (argc, argv, "agnruG", longopts, (int *) 0))
 	 != EOF)
     {
       switch (optc)
 	{
 	case 0:
 	  break;
+	case 'a':
+	  /* Ignore -a, for compatibility with SVR4.  */
+	  break;
 	case 'g':
 	  just_group = 1;
 	  break;
@@ -140,7 +136,7 @@ main (argc, argv)
 
   if (show_version)
     {
-      printf ("id - %s\n", version_string);
+      printf ("id (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (0);
     }
 
@@ -148,10 +144,10 @@ main (argc, argv)
     usage (0);
 
   if (just_user + just_group + just_group_list > 1)
-    error (1, 0, "cannot print only user and only group");
+    error (1, 0, _("cannot print only user and only group"));
 
   if (just_user + just_group + just_group_list == 0 && (use_real || use_name))
-    error (1, 0, "cannot print only names or real IDs in default format");
+    error (1, 0, _("cannot print only names or real IDs in default format"));
 
   if (argc - optind > 1)
     usage (1);
@@ -160,7 +156,7 @@ main (argc, argv)
     {
       struct passwd *pwd = getpwnam (argv[optind]);
       if (pwd == NULL)
-	error (1, 0, "%s: No such user", argv[optind]);
+	error (1, 0, _("%s: No such user"), argv[optind]);
       ruid = euid = pwd->pw_uid;
       rgid = egid = pwd->pw_gid;
     }
@@ -188,8 +184,7 @@ main (argc, argv)
 /* Print the name or value of user ID UID. */
 
 static void
-print_user (uid)
-     int uid;
+print_user (int uid)
 {
   struct passwd *pwd = NULL;
 
@@ -209,8 +204,7 @@ print_user (uid)
 /* Print the name or value of group ID GID. */
 
 static void
-print_group (gid)
-     int gid;
+print_group (int gid)
 {
   struct group *grp = NULL;
 
@@ -227,11 +221,44 @@ print_group (gid)
     printf ("%s", grp->gr_name);
 }
 
-/* Print all of the distinct groups the user is in . */
+static int
+xgetgroups (const char *username, int *n_groups, GETGROUPS_T **groups)
+{
+  int max_n_groups;
+  int ng;
+  GETGROUPS_T *g;
+  int fail = 0;
+
+  if (username == 0)
+    max_n_groups = getgroups (0, NULL);
+  else
+    max_n_groups = getugroups (0, NULL, username);
+
+  /* Add 1 just in case max_n_groups is zero.  */
+  g = (GETGROUPS_T *) xmalloc (max_n_groups * sizeof (GETGROUPS_T) + 1);
+  if (username == 0)
+    ng = getgroups (max_n_groups, g);
+  else
+    ng = getugroups (max_n_groups, g, username);
+
+  if (ng < 0)
+    {
+      error (0, errno, _("cannot get supplemental group list"));
+      ++fail;
+      free (groups);
+    }
+  if (!fail)
+    {
+      *n_groups = ng;
+      *groups = g;
+    }
+  return fail;
+}
+
+/* Print all of the distinct groups the user is in. */
 
 static void
-print_group_list (username)
-     char *username;
+print_group_list (char *username)
 {
   print_group (rgid);
   if (egid != rgid)
@@ -240,26 +267,19 @@ print_group_list (username)
       print_group (egid);
     }
 
-#if defined(NGROUPS_MAX) && defined(HAVE_GETGROUPS)
+#if HAVE_GETGROUPS
   {
-    int ngroups;
+    int n_groups;
     GETGROUPS_T *groups;
     register int i;
 
-    groups = (GETGROUPS_T *) xmalloc (NGROUPS_MAX * sizeof (GETGROUPS_T));
-    if (username == 0)
-      ngroups = getgroups (NGROUPS_MAX, groups);
-    else
-      ngroups = getugroups (NGROUPS_MAX, groups, username);
-    if (ngroups < 0)
+    if (xgetgroups (username, &n_groups, &groups))
       {
-	error (0, errno, "cannot get supplemental group list");
-	problems++;
-	free (groups);
+	++problems;
 	return;
       }
 
-    for (i = 0; i < ngroups; i++)
+    for (i = 0; i < n_groups; i++)
       if (groups[i] != rgid && groups[i] != egid)
 	{
 	  putchar (' ');
@@ -273,8 +293,7 @@ print_group_list (username)
 /* Print all of the info about the user's user and group IDs. */
 
 static void
-print_full_info (username)
-     char *username;
+print_full_info (char *username)
 {
   struct passwd *pwd;
   struct group *grp;
@@ -285,14 +304,14 @@ print_full_info (username)
     problems++;
   else
     printf ("(%s)", pwd->pw_name);
-  
+
   printf (" gid=%u", (unsigned) rgid);
   grp = getgrgid (rgid);
   if (grp == NULL)
     problems++;
   else
     printf ("(%s)", grp->gr_name);
-  
+
   if (euid != ruid)
     {
       printf (" euid=%u", (unsigned) euid);
@@ -302,7 +321,7 @@ print_full_info (username)
       else
 	printf ("(%s)", pwd->pw_name);
     }
-  
+
   if (egid != rgid)
     {
       printf (" egid=%u", (unsigned) egid);
@@ -313,28 +332,21 @@ print_full_info (username)
 	printf ("(%s)", grp->gr_name);
     }
 
-#if defined(NGROUPS_MAX) && defined(HAVE_GETGROUPS)
+#if HAVE_GETGROUPS
   {
-    int ngroups;
+    int n_groups;
     GETGROUPS_T *groups;
     register int i;
 
-    groups = (GETGROUPS_T *) xmalloc (NGROUPS_MAX * sizeof (GETGROUPS_T));
-    if (username == 0)
-      ngroups = getgroups (NGROUPS_MAX, groups);
-    else
-      ngroups = getugroups (NGROUPS_MAX, groups, username);
-    if (ngroups < 0)
+    if (xgetgroups (username, &n_groups, &groups))
       {
-	error (0, errno, "cannot get supplemental group list");
-	problems++;
-	free (groups);
+	++problems;
 	return;
       }
 
-    if (ngroups > 0)
-      fputs (" groups=", stdout);
-    for (i = 0; i < ngroups; i++)
+    if (n_groups > 0)
+      fputs (_(" groups="), stdout);
+    for (i = 0; i < n_groups; i++)
       {
 	if (i > 0)
 	  putchar (',');
@@ -351,17 +363,18 @@ print_full_info (username)
 }
 
 static void
-usage (status)
-     int status;
+usage (int status)
 {
   if (status != 0)
-    fprintf (stderr, "Try `%s --help' for more information.\n",
+    fprintf (stderr, _("Try `%s --help' for more information.\n"),
 	     program_name);
   else
     {
-      printf ("Usage: %s [OPTION]... [USERNAME]\n", program_name);
-      printf ("\
+      printf (_("Usage: %s [OPTION]... [USERNAME]\n"), program_name);
+      printf (_("\
+Print information for USERNAME, or the current user.\n\
 \n\
+  -a              ignore, for compatibility with other versions\n\
   -g, --group     print only the group ID\n\
   -G, --groups    print only the supplementary groups\n\
   -n, --name      print a name instead of a number, for -ugG\n\
@@ -371,7 +384,8 @@ usage (status)
       --version   output version information and exit\n\
 \n\
 Without any OPTION, print some useful set of identified information.\n\
-");
+"));
+      puts (_("\nReport bugs to sh-utils-bugs@gnu.ai.mit.edu"));
     }
   exit (status);
 }
